import { ArgumentOutOfRangeException } from '@mobicoop/ddd-library';
import { Point } from '@modules/ad/core/domain/value-objects/point.value-object';

describe('Point value object', () => {
  it('should create a point value object', () => {
    const pointVO = new Point({
      lat: 48.689445,
      lon: 6.17651,
    });
    expect(pointVO.lat).toBe(48.689445);
    expect(pointVO.lon).toBe(6.17651);
  });
  it('should check if two points are identical', () => {
    const pointVO = new Point({
      lat: 48.689445,
      lon: 6.17651,
    });
    const identicalPointVO = new Point({
      lat: 48.689445,
      lon: 6.17651,
    });
    const differentPointVO = new Point({
      lat: 48.689446,
      lon: 6.17651,
    });
    expect(pointVO.isSame(identicalPointVO)).toBeTruthy();
    expect(pointVO.isSame(differentPointVO)).toBeFalsy();
  });
  it('should throw an exception if longitude is invalid', () => {
    try {
      new Point({
        lat: 48.689445,
        lon: 186.17651,
      });
    } catch (e: any) {
      expect(e).toBeInstanceOf(ArgumentOutOfRangeException);
    }
    try {
      new Point({
        lat: 48.689445,
        lon: -186.17651,
      });
    } catch (e: any) {
      expect(e).toBeInstanceOf(ArgumentOutOfRangeException);
    }
  });
  it('should throw an exception if latitude is invalid', () => {
    try {
      new Point({
        lat: 148.689445,
        lon: 6.17651,
      });
    } catch (e: any) {
      expect(e).toBeInstanceOf(ArgumentOutOfRangeException);
    }
    try {
      new Point({
        lat: -148.689445,
        lon: 6.17651,
      });
    } catch (e: any) {
      expect(e).toBeInstanceOf(ArgumentOutOfRangeException);
    }
  });
});
