import { HasValidPositionIndexes } from '@modules/ad/interface/grpc-controllers/dtos/validators/decorators/has-valid-position-indexes.decorator';
import { WaypointDto } from '@modules/ad/interface/grpc-controllers/dtos/waypoint.dto';
import { Validator } from 'class-validator';

describe('valid position indexes decorator', () => {
  class MyClass {
    @HasValidPositionIndexes()
    waypoints: WaypointDto[];
  }
  it('should return a property decorator has a function', () => {
    const hasValidPositionIndexes = HasValidPositionIndexes();
    expect(typeof hasValidPositionIndexes).toBe('function');
  });
  it('should validate an array of waypoints with valid positions', async () => {
    const myClassInstance = new MyClass();
    myClassInstance.waypoints = [
      {
        position: 0,
        lon: 48.8566,
        lat: 2.3522,
        locality: 'Paris',
        postalCode: '75000',
        country: 'France',
      },
      {
        position: 1,
        lon: 49.2628,
        lat: 4.0347,
        locality: 'Reims',
        postalCode: '51454',
        country: 'France',
      },
    ];
    const validator = new Validator();
    const validation = await validator.validate(myClassInstance);
    expect(validation.length).toBe(0);
  });
  it('should not validate an array of waypoints with invalid positions', async () => {
    const myClassInstance = new MyClass();
    myClassInstance.waypoints = [
      {
        position: 1,
        lon: 48.8566,
        lat: 2.3522,
        locality: 'Paris',
        postalCode: '75000',
        country: 'France',
      },
      {
        position: 1,
        lon: 49.2628,
        lat: 4.0347,
        locality: 'Reims',
        postalCode: '51454',
        country: 'France',
      },
    ];
    const validator = new Validator();
    const validation = await validator.validate(myClassInstance);
    expect(validation.length).toBe(1);
  });
});
