import { DefaultParams } from '@modules/geography/core/application/types/default-params.type';
import { DefaultParamsProvider } from '@modules/geography/infrastructure/default-params-provider';
import { ConfigService } from '@nestjs/config';
import { Test, TestingModule } from '@nestjs/testing';

const mockConfigService = {
  get: jest.fn().mockImplementation((value: string) => {
    switch (value) {
      case 'GEOROUTER_TYPE':
        return 'graphhopper';
      case 'GEOROUTER_URL':
        return 'http://localhost:8989';
      default:
        return 'some_default_value';
    }
  }),
};

describe('DefaultParamsProvider', () => {
  let defaultParamsProvider: DefaultParamsProvider;

  beforeAll(async () => {
    const module: TestingModule = await Test.createTestingModule({
      imports: [],
      providers: [
        DefaultParamsProvider,
        {
          provide: ConfigService,
          useValue: mockConfigService,
        },
      ],
    }).compile();

    defaultParamsProvider = module.get<DefaultParamsProvider>(
      DefaultParamsProvider,
    );
  });

  it('should be defined', () => {
    expect(defaultParamsProvider).toBeDefined();
  });

  it('should provide default params', async () => {
    const params: DefaultParams = defaultParamsProvider.getParams();
    expect(params.GEOROUTER_TYPE).toBe('graphhopper');
    expect(params.GEOROUTER_URL).toBe('http://localhost:8989');
  });
});
